// Import necessary packages from d3
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.5~g')(number);

	//creating the chart
	const render = data => {
  const pieData = pie().sort(null).value(d=>d.Marks)(data);
  
	//Choosing the color palette
  const colors = scaleOrdinal(d3.schemeCategory10)
  	.domain(data);
  	
  //creating arc for the circle 
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(185)
  	.padAngle(0)
  	.padRadius(0);
 // retrieving the data  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,200)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Marks));  
  
//creating the legend for the chart
  const legends = svg.append("g")
  	.attr("transform", "translate(500,10)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*35})`;
    });
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Marks));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Name);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat(d.data.Marks));
}

//Loading the dataset from .json file
json( 'Data.json' ).then(data => {
  data.forEach(d=>{
    d.Marks = +d.Marks;
  });
  render(data);
}) 